MissionDurationConstraintRule

Struct MissionDurationConstraintRule 

pub struct MissionDurationConstraintRule { /* private fields */ }
Rule for determining mission duration constraint

Mission duration is limited by the platform with shortest endurance. Critical for planning operations that require the entire team.

Implementations

Source

impl MissionDurationConstraintRule

pub fn new(min_platforms: usize) -> Self

Create a new mission duration constraint rule