pub struct PeatCredentials { /* private fields */ }Expand description
Peat credentials for backend authentication.
Implementations
Sourceimpl PeatCredentials
impl PeatCredentials
Sourcepub fn new(app_id: String, secret_key: Option<String>) -> Self
pub fn new(app_id: String, secret_key: Option<String>) -> Self
Create credentials from explicit values.
Sourcepub fn from_env() -> Result<Self, CredentialsError>
pub fn from_env() -> Result<Self, CredentialsError>
Load credentials from environment variables.
Reads PEAT_APP_ID (required) and PEAT_SECRET_KEY (or
PEAT_SHARED_KEY as an alias, optional).
Sourcepub fn try_from_env() -> Option<Self>
pub fn try_from_env() -> Option<Self>
Load credentials from environment, returning None if not configured.
Sourcepub fn is_configured() -> bool
pub fn is_configured() -> bool
Whether PEAT_APP_ID is configured in the environment.
Sourcepub fn secret_key(&self) -> Option<&str>
pub fn secret_key(&self) -> Option<&str>
Shared secret key, if configured.
Sourcepub fn has_secret_key(&self) -> bool
pub fn has_secret_key(&self) -> bool
Whether a secret key is configured.
Sourcepub fn require_secret_key(&self) -> Result<&str, CredentialsError>
pub fn require_secret_key(&self) -> Result<&str, CredentialsError>
Get the secret key, or return an error if missing.