#[repr(i32)]pub enum EventClass {
Unspecified = 0,
Product = 1,
Anomaly = 2,
Telemetry = 3,
Command = 4,
}Expand description
Event classification determines handling behavior
Variants
Unspecified = 0
Product = 1
Outputs from software (detections, decisions, classifications)
Anomaly = 2
Anomalies requiring attention (unusual patterns, alerts)
Telemetry = 3
Metrics, health, diagnostics
Command = 4
Downward directives (commands flowing down hierarchy)
Implementations
Sourceimpl EventClass
impl EventClass
Sourceimpl EventClass
impl EventClass
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<EventClass>
pub fn from_str_name(value: &str) -> Option<EventClass>
Creates an enum from field names used in the ProtoBuf definition.