#[repr(i32)]pub enum EventPriority {
PriorityCritical = 0,
PriorityHigh = 1,
PriorityNormal = 2,
PriorityLow = 3,
}Expand description
Event priority for transmission scheduling CRITICAL events preempt all other traffic
Variants
PriorityCritical = 0
Immediate transmission, preempts other traffic
PriorityHigh = 1
High priority, after CRITICAL
PriorityNormal = 2
Normal priority (default)
PriorityLow = 3
Low priority, transmitted when bandwidth available
Implementations
Sourceimpl EventPriority
impl EventPriority
Sourceimpl EventPriority
impl EventPriority
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<EventPriority>
pub fn from_str_name(value: &str) -> Option<EventPriority>
Creates an enum from field names used in the ProtoBuf definition.