pub struct AggregationPolicy {
pub propagation: i32,
pub priority: i32,
pub ttl_seconds: u32,
pub aggregation_window_ms: u32,
}Expand description
Aggregation and routing policy for events
Fields
propagation: i32How this event should propagate through the hierarchy
priority: i32Priority for transmission scheduling
ttl_seconds: u32Time-to-live in seconds (0 = no expiry)
aggregation_window_ms: u32Aggregation window in milliseconds for SUMMARY mode Events within this window are batched into a single summary
Implementations
Sourceimpl AggregationPolicy
impl AggregationPolicy
Sourcepub fn propagation(&self) -> PropagationMode
pub fn propagation(&self) -> PropagationMode
Returns the enum value of propagation, or the default if the field is set to an invalid enum value.
Sourcepub fn set_propagation(&mut self, value: PropagationMode)
pub fn set_propagation(&mut self, value: PropagationMode)
Sets propagation to the provided enum value.
Sourcepub fn priority(&self) -> EventPriority
pub fn priority(&self) -> EventPriority
Returns the enum value of priority, or the default if the field is set to an invalid enum value.
Sourcepub fn set_priority(&mut self, value: EventPriority)
pub fn set_priority(&mut self, value: EventPriority)
Sets priority to the provided enum value.