EventQueryHandler

Struct EventQueryHandler 

pub struct EventQueryHandler { /* private fields */ }
Handler for event queries

Processes incoming queries, applying filters to the local event store and optionally forwarding queries to subordinates.

Implementations

Source

impl EventQueryHandler

pub fn new( node_id: String, formation_id: String, event_store: Arc<dyn EventStore>, ) -> Self

Create a new query handler

pub fn with_memory_store(node_id: String, formation_id: String) -> Self

Create a new query handler with a default in-memory store

pub fn add_subordinate(&self, node_id: &str)

Register a subordinate node

pub fn remove_subordinate(&self, node_id: &str)

Remove a subordinate node

pub fn node_id(&self) -> &str

Get the node ID

pub fn formation_id(&self) -> &str

Get the formation ID

pub fn store_event(&self, event: PeatEvent)

Store an event in the local store

pub fn event_count(&self) -> usize

Get count of stored events

pub fn handle_query(&self, query: &EventQuery) -> QueryResult

Handle an incoming query

For local queries (node_id matches), returns results from local store. For subordinate queries, returns information about which nodes should be queried.

pub fn query_local(&self, query: &EventQuery) -> EventQueryResponse

Query the local event store

pub fn merge_responses( query_id: &str, responder_id: &str, responses: Vec<EventQueryResponse>, limit: u32, ) -> EventQueryResponse

Merge multiple query responses into one

pub fn create_node_query( requester_id: &str, node_id: &str, filters: Option<EventFilters>, limit: u32, ) -> EventQuery

Create a query for a specific node

pub fn create_formation_query( requester_id: &str, formation_id: &str, filters: Option<EventFilters>, limit: u32, ) -> EventQuery

Create a query for a formation

pub fn create_subordinates_query( requester_id: &str, filters: Option<EventFilters>, limit: u32, ) -> EventQuery

Create a query for all subordinates

pub fn enforce_ttl(&self)

Remove expired events from the store