#[repr(i32)]pub enum BindingType {
Unspecified = 0,
OneToOne = 1,
OneToMany = 2,
ManyToOne = 3,
ManyToMany = 4,
}Expand description
Binding type for human-machine pairs
Variants
Unspecified = 0
OneToOne = 1
One operator, one platform
OneToMany = 2
One operator, multiple platforms (swarm)
ManyToOne = 3
Multiple operators, one platform
ManyToMany = 4
Multiple operators, multiple platforms
Implementations
Sourceimpl BindingType
impl BindingType
Sourceimpl BindingType
impl BindingType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<BindingType>
pub fn from_str_name(value: &str) -> Option<BindingType>
Creates an enum from field names used in the ProtoBuf definition.