#[repr(i32)]pub enum ProtoDeviceType {
Unspecified = 0,
Uav = 1,
Ugv = 2,
Usv = 3,
SoldierSystem = 4,
C2Station = 5,
RelayNode = 6,
SensorPlatform = 7,
}Expand description
Device type classification per ADR-006
Variants
Unspecified = 0
Uav = 1
Unmanned Aerial Vehicle
Ugv = 2
Unmanned Ground Vehicle
Usv = 3
Unmanned Surface Vehicle
SoldierSystem = 4
Soldier/Dismounted System
C2Station = 5
Command & Control Station
RelayNode = 6
Relay/Communication Node
SensorPlatform = 7
Sensor Platform (static)
Implementations
Sourceimpl DeviceType
impl DeviceType
Sourceimpl DeviceType
impl DeviceType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<DeviceType>
pub fn from_str_name(value: &str) -> Option<DeviceType>
Creates an enum from field names used in the ProtoBuf definition.