pub struct NegentropySync { /* private fields */ }Expand description
Manager for Negentropy-based document sync
Provides efficient O(log n) set reconciliation to discover which documents need to be synced, avoiding unbounded Automerge sync state.
Implementations
Sourceimpl NegentropySync
impl NegentropySync
Sourcepub fn new() -> NegentropySync
pub fn new() -> NegentropySync
Create a new NegentropySync manager
Sourcepub fn initiate_sync(
&self,
peer_id: PublicKey,
local_items: Vec<SyncItem>,
) -> Result<Vec<u8>, Error>
pub fn initiate_sync( &self, peer_id: PublicKey, local_items: Vec<SyncItem>, ) -> Result<Vec<u8>, Error>
Start a sync session with a peer as initiator
Returns the initial message to send to the peer.
Sourcepub fn handle_message(
&self,
peer_id: PublicKey,
message: &[u8],
local_items: Vec<SyncItem>,
) -> Result<ReconcileResult, Error>
pub fn handle_message( &self, peer_id: PublicKey, message: &[u8], local_items: Vec<SyncItem>, ) -> Result<ReconcileResult, Error>
Handle incoming sync message from peer
If we have an active session, this is a response to our initiation. Otherwise, we’re the responder and should create a new session.
Sourcepub fn stats(&self) -> NegentropyStats
pub fn stats(&self) -> NegentropyStats
Get current statistics
Sourcepub fn has_session(&self, peer_id: &PublicKey) -> bool
pub fn has_session(&self, peer_id: &PublicKey) -> bool
Check if there’s an active session with a peer
Sourcepub fn cancel_session(&self, peer_id: &PublicKey)
pub fn cancel_session(&self, peer_id: &PublicKey)
Cancel a sync session