#[repr(i32)]pub enum Phase {
Unspecified = 0,
Discovery = 1,
Cell = 2,
Hierarchy = 3,
}Expand description
Protocol phase enumeration
Variants
Unspecified = 0
Discovery = 1
Discovery phase (beacon broadcasting)
Cell = 2
Cell formation phase
Hierarchy = 3
Hierarchical operations phase
Implementations
Sourceimpl Phase
impl Phase
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Phase>
pub fn from_str_name(value: &str) -> Option<Phase>
Creates an enum from field names used in the ProtoBuf definition.