pub struct MissionDurationConstraintRule { /* private fields */ }Expand description
Rule for determining mission duration constraint
Mission duration is limited by the platform with shortest endurance. Critical for planning operations that require the entire team.
Implementations