pub struct CompositionContext {
pub node_ids: Vec<String>,
pub cell_id: Option<String>,
pub timestamp: SystemTime,
pub node_configs: Vec<NodeConfig>,
}Expand description
Context for rule execution
Provides additional information that rules may need for composition decisions.
Fields
node_ids: Vec<String>Node IDs contributing capabilities
cell_id: Option<String>Cell or squad ID if composing within a cell
timestamp: SystemTimeTimestamp of composition (for temporal analysis)
node_configs: Vec<NodeConfig>Node configurations (for operator/authority checks)
Implementations
Sourceimpl CompositionContext
impl CompositionContext
Sourcepub fn with_cell_id(self, cell_id: String) -> Self
pub fn with_cell_id(self, cell_id: String) -> Self
Set the cell ID for this composition
Sourcepub fn with_node_configs(self, configs: Vec<NodeConfig>) -> Self
pub fn with_node_configs(self, configs: Vec<NodeConfig>) -> Self
Add node configurations for operator/authority checks
Get the maximum authority level among all operators in the context
Sourcepub fn has_commander(&self) -> bool
pub fn has_commander(&self) -> bool
Check if any node has an operator with Commander authority
Get authorization bonus (0-5 scale) based on max authority