pub struct Operator {
pub id: String,
pub name: String,
pub rank: i32,
pub authority_level: i32,
pub mos: String,
pub metadata_json: String,
}Expand description
Human operator information
Fields
id: StringUnique operator identifier
name: StringOperator name
rank: i32Military rank
Authority level
mos: StringMilitary Occupational Specialty (MOS)
metadata_json: StringAdditional operator metadata
Implementations
Sourceimpl Operator
impl Operator
Sourcepub fn rank(&self) -> OperatorRank
pub fn rank(&self) -> OperatorRank
Returns the enum value of rank, or the default if the field is set to an invalid enum value.
Sourcepub fn set_rank(&mut self, value: OperatorRank)
pub fn set_rank(&mut self, value: OperatorRank)
Sets rank to the provided enum value.
Returns the enum value of authority_level, or the default if the field is set to an invalid enum value.
Sets authority_level to the provided enum value.