pub trait AuthorityLevelExt {
// Required methods
fn to_score(self) -> f64;
fn can_override(self) -> bool;
fn requires_approval(self) -> bool;
}Required Methods
Sourcefn can_override(self) -> bool
fn can_override(self) -> bool
Check if this authority level can override machine decisions
Sourcefn requires_approval(self) -> bool
fn requires_approval(self) -> bool
Check if this authority level requires human approval for actions